/** @file
 * @brief Serviceholder class header. This class holds Service and OldService lists.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef SERVICEHOLDER_H
#define SERVICEHOLDER_H

#include "service.h"
#include "serializeservicecontainer.h"
#include "logger.h"

#include <boost/shared_ptr.hpp>
#include <list>


class Serviceholder
{

private:

    Logger::Ptr Log;

    std::list<Service::Ptr> OldServices;      // Represents all old Services where the timeout isn't expired (in case the same Service is redefined).
    std::list<Service::Ptr> Services;         // Represents all active Services.

public:

    typedef boost::shared_ptr<Serviceholder> Ptr;

    Serviceholder(Logger::Ptr _log);

    ~Serviceholder();

    void add_service(Service::Ptr service);

    int deserialize_services();

    int serialize_services();

    void delete_services();

    std::list<Service::Ptr> get_services() const;
};

#endif
